Arguments
rangeval
a vector of length 2 containing the initial and final
values of the interval over which the functional
data object can be evaluated. Default value c(0,1)
nbasis
an integer variable specifying the number of basis functions. The
number of basis functions is always odd, even when an even number
is specified, so as to preserve the pairing of sine and cosine
functions. Default value 3.
period
the width of any interval over which the Fourier functions repeat
themselves, or are periodic. The default is the width of the
interval defined in rangeval.
dropind
a vector of integers specifiying the basis functions to
be dropped, if any. For example, if it is required that
a function be zero at the left boundary, this is achieved
by dropping the first basis function, the only one that
is nonzero at that point. De
quadvals
a matrix with two columns and a number of rows equal to the number of
argument values used to approximate an integral using Simpson's rule.
The first column contains these argument values.
A minimum of 5 values are required for
each inter-knot interval, a
values
a list containing the basis functions and their derivatives
evaluated at the quadrature points contained in the first
column of quadvals.