cycleplot.fd: Plot Cycles for a Periodic Bivariate Functional Data Object
Description
A plotting function for data such as the knee-hip angles in
the gait data or temperature-precipitation curves for the
weather data.Usage
cycleplot.fd(fdobj, matplt=TRUE, nx=201, ...)
Arguments
fdobj
a bivariate functional data object to be plotted.
matplt
if TRUE, all cycles are plotted simultaneously; otherwise
each cycle in turn is plotted.
nx
the number of argument values in a fine mesh to be
plotted. Increase the default number of 201 if
the curves have a lot of detail in them.
...
additional plotting parameters such as axis labels and
etc. that are used in all plot functions.
Side Effects
A plot of the cyclesSee Also
plot.fd, plotfit.fd, demo(gait)