eval.basis: Values of Basis Functions or their Derivatives
Description
A set of basis functions are evaluated at a vector of
argument values. If a linear differential object is
the values are of the result of applying the the operator
to each basis function.
Usage
eval.basis(evalarg, basisobj, Lfdobj=0)
Arguments
evalarg
a vector of argument values.
basisobj
a basis object defining basis functions whose values
are to be computed.
Lfdobj
either a nonnegative integer or a linear differential.
operator object.
Value
a matrix of basis function values with rows corresponding
to argument values and columns to basis functions.
Details
Note that if a linear differential operator object is supplied,
the basis must be such that the highest order derivative can be
computed. If a B-spline basis is used, for example, its order
must be one larger than the highest order of derivative
required.