evaldiag.bifd: Evaluate the Diagonal of a Bivariate Functional Data Object
Description
Bivariate function data objects are functions of
two arguments, $f(s,t)$. It can be useful to evaluate
the function for argument values satisying $s=t$, such
as evaluating the univariate variance function given the
bivariate function that defines the variance-covariance
function or surface. A linear differential operator can
be applied to function $f(s,t)$ considered as a univariate
function of either object holding the other object fixed.Usage
evaldiag.bifd(evalarg, bifdobj, sLfd=int2Lfd(0),
tLfd=int2Lfd(0))Arguments
evalarg
a vector of values of $s = t$.
bifdobj
a bivariate functional data object of the bifd class.
sLfd
either a nonnegative integer or a linear differential operator
object.
tLfd
either a nonnegative integer or a linear differential operator
object.
Value
- a vector or matrix of diagonal function values.
See Also
var.fd, eval.bifd