fRegress carries out a functional regression analysis
of the concurrent kind, and estimates a regression coefficient
function corresponding to each independent variable, whether it is
scalar or functional. This function uses the list that is output by
fRegress to provide standard error functions for each
regression function. These standard error functions are pointwise,
meaning that sampling standard deviation functions only are computed,
and not sampling covariances.fRegress.stderr(y, y2cMap, SigmaE, ...)fRegress.smooth.basis that generatesfRegress.stderr but needed for
superficial compatibability with fRegress methods.fRegress,
fRegress.CV#See the weather data analyses in the file daily.ssc for
#examples of the use of function fRegress.stderr.Run the code above in your browser using DataLab