fd class.
Each function that sets up an object of this class must call this function.
This includes functions data2fd,
smooth.basis, density.fd, and
so forth that estimate functional data objects that smooth or otherwise
represent data. Ordinarily, user
of the functional data analysis software will not need to call this function
directly, but these notes are valuable to understanding what the "slots"
or "members" of the fd class are.fd(coef=matrix(0, 2, 1), basisobj=basisfd(),
fdnames=defaultnames)is.fd.Normally only developers of new functional data analysis functions will actually need to use this function, so no examples are provided.