Evaluates a set of Fourier basis functions, or a derivative of these
functions, at a set of arguments.
Usage
fourier(x, nbasis=n, period=span, nderiv=0)
Arguments
x
a vector of argument values at which the Fourier basis functions are to
evaluated.
nbasis
the number of basis functions in the Fourier basis. The first basis
function is the constant function, followed by sets of sine/cosine
pairs. Normally the number of basis functions will be an odd. The
default number is the number of argument values.
period
the width of an interval over which all sine/cosine basis functions
repeat themselves. The default is the difference between the largest
and smallest argument values.
nderiv
the derivative to be evaluated. The derivative must not exceed the
order. The default derivative is 0, meaning that the basis functions
themselves are evaluated.
Value
a matrix of function values. The number of rows equals the number of
arguments, and the number of columns equals the number of basis functions.
# set up a set of 11 argument valuesx <- seq(0,1,0.1)
# compute values for five Fourier basis functions# with the default period (1) and derivative (0)basismat <- fourier(x, 5)