Rdocumentation
powered by
Learn R Programming
fda (version 1.1.1)
sum.fd: Sum of Functional Data
Description
Evaluate the sum of a set of functions in a functional data object.
Usage
sum.fd(..., na.rm)
Arguments
...
a functional data object to sum.
na.rm
Not used.
Value
a functional data object with a single replication that contains the sum of the functions in the object
fd
.
See Also
mean.fd, std.fd, stddev.fd, center.fd